@@ -145,9 +145,9 @@ def _copyFiles(files: List[str], dest: str, verbose=False) -> None:
         shutil.copy(f, dest)
 
 
-def pluginsInstalled(force=False) -> bool:
+def pluginsInstalled(cached=True) -> bool:
     """Returns True if the needed plugins are already installed"""
-    opcodes = set(csoundlib.opcodesList(cached=not force,
+    opcodes = set(csoundlib.opcodesList(cached=cached,
                                         opcodedir=csoundlib.userPluginsFolder()))
     neededOpcodes = {
         "atstop", "pwrite", "pread", "initerror",
@@ -184,38 +184,40 @@ def _installPluginsFromZipFile(zipped: Path):
     else:
         raise OSError(f"Platform {sys.platform} not supported")
     _copyFiles(plugins, pluginsFolder, verbose=True)
-    if not pluginsInstalled(force=True):
+    if not pluginsInstalled(cached=False):
         raise RuntimeError("There was an error in the installation...")
 
 
 def _installPluginsFromDist():
-    rootfolder = Path(os.path.split(__file__)[0])
+    rootfolder = Path(os.path.split(__file__)[0]).parent
     assert rootfolder.exists()
-    if sys.platform == 'darwin':
-        pluginspath = rootfolder / 'plugins/macos'
-        if not pluginspath.exists():
-            raise RuntimeError(f"Could not find own csound packages. Folder: {pluginspath}")
-        plugins = pluginspath.glob("*.dylib")
-    elif sys.platform == 'windows':
-        pluginspath = rootfolder/'plugins/windows'
-        if not pluginspath.exists():
-            raise RuntimeError(f"Could not find own csound packages. Folder: {pluginspath}")
-        plugins = pluginspath.glob("*.dll")
-    elif sys.platform == 'linux':
-        pluginspath = rootfolder/'plugins/linux'
-        if not pluginspath.exists():
-            raise RuntimeError(f"Could not find own csound packages. Folder: {pluginspath}")
-        plugins = pluginspath.glob("*.dll")
-    else:
+    subfolder, globpattern = {
+        'darwin': ('macos', '*.dylib'),
+        'windows': ('windows', '*.dll'),
+        'linux': ('linux', '*.so')
+    }.get(sys.platform, (None, None))
+    if subfolder is None:
         raise RuntimeError(f"Platform {sys.platform} not supported")
+    pluginspath = rootfolder/'data/plugins'/subfolder
+    if not pluginspath.exists():
+        raise RuntimeError(f"Could not find own csound plugins. Folder: {pluginspath}")
+    plugins = list(pluginspath.glob(globpattern))
+    if not plugins:
+        logger.error(f"Plugins not found. Plugins folder: {pluginspath}, "
+                     f"glob patter: {globpattern}")
+        raise RuntimeError("Plugins not found")
     pluginsDest = csoundlib.userPluginsFolder()
     os.makedirs(pluginsDest, exist_ok=True)
     _copyFiles([plugin.as_posix() for plugin in plugins], pluginsDest, verbose=True)
+    if not pluginsInstalled(cached=False):
+        raise RuntimeError("There was an error in the installation")
 
 
 def installPlugins() -> None:
     """
     Install all needed plugins
+
+    Will raise RuntimeError if failed
     """
     if pluginsInstalled():
         logger.info("Plugins are already installed, installed plugins will be "
@@ -223,8 +225,12 @@ def installPlugins() -> None:
     try:
         zipped = downloadLatestPluginForPlatform()
         _installPluginsFromZipFile(zipped)
-    except RuntimeError:
-        _installPluginsFromDist()
+        return
+    except RuntimeError as e:
+        logger.error(f"Could not install plugins from github: {e}")
+    logger.info("Installing plugins from distribution")
+    _installPluginsFromDist()
+    logger.info("<<< Plugins installed successfully! >>>")
 
 
 def _checkDependencies(tryfix=False, updateState=True) -> Optional[str]:
